--------------------------------------------------------------------------
--  _   _ _____ ____       ____   ___   __     __    _       _
-- | | | | ____/ ___|     / ___| / _ \  \ \   / /_ _| | __ _(_)___
-- | |_| |  _| \___ \ ____\___ \| | | |  \ \ / / _` | |/ _` | / __|
-- |  _  | |___ ___) |_____|__) | |_| |   \ V / (_| | | (_| | \__ \
-- |_| |_|_____|____/     |____/ \___/     \_/ \__,_|_|\__,_|_|___/
--
-----------------------------------------------------------------------------
-----------------------------------------------------------------------------
-- Author(s) : Marc Pignat, Pierre-Andr Mudry
-----------------------------------------------------------------------------
library ieee;
	use ieee.std_logic_1164.all;
	use ieee.numeric_std.all;

library unisim;
	use unisim.vcomponents.all;

entity clock_output_inverting_xilinx is
	port
	(
		clock_in			: in	std_logic;
		clock_out			: out	std_logic
	);
end clock_output_inverting_xilinx;

architecture rtl of clock_output_inverting_xilinx is
	signal clock_in_not	: std_logic;
begin

    -------------------------------------------------------------------------------
    -- Clock forwarding
    --
    -- The oddr2 is used to output a clock, so we can add constraint between this
    -- output and the others audio signals
    -------------------------------------------------------------------------------
	clock_in_not <= not clock_in;

    i_oddr : oddr2
    generic map
    (
        ddr_alignment => "c1",    -- sets output alignment to "none", "c0", "c1"
        init          => '0',     -- sets initial state of the q output to '0' or '1'
        srtype        => "async"  -- specifies "sync" or "async" set/reset
    )
    port map
    (
        q  => clock_out,
        c0 => clock_in,
        c1 => clock_in_not,
        ce => '1',
        d0 => '1',
        d1 => '0',
        r  => '0',
        s  => '0'
    );

end architecture rtl;

